@@ -27,9 +27,12 @@ for i, v in enumerate(data['include']):
                     'repo_distro': data['include'][i]['packages']['repo_distro'],
                     'format': data['include'][i]['packages']['type'],
                     'base_image': data['include'][i]['base_image'] if 'base_image' in data['include'][i] else ':'.join([data['include'][i]['distro'], data['include'][i]['version']]),
+                    'builder_rev': data['include'][i]['packages']['builder_rev'],
                     'platform': data['platform_map'][arch],
-                    'bundle_sentry': data['include'][i]['bundle_sentry'],
-                    'arch': arch
+                    'bundle_sentry': data['include'][i]['bundle_sentry'][arch],
+                    'arch': arch,
+                    'runner': data['arch_data'][arch]['runner'],
+                    'qemu': data['arch_data'][arch]['qemu'],
                 })
 
 entries.sort(key=lambda k: (data['arch_order'].index(k['arch']), k['distro'], k['version']))
